@@ -1,6 +1,6 @@
 package SADI::Simple;
 BEGIN {
-  $SADI::Simple::VERSION = '0.003';
+  $SADI::Simple::VERSION = '0.004';
 }
 
 1;
@@ -41,7 +41,7 @@ SADI::Simple - Module for creating Perl SADI services.
         OutputClass => 'http://sadiframework.org/examples/hello.owl#GreetedIndividual',   
         Description => 'A \'Hello, World!\' service',
         Provider => 'myaddress@organization.org',
-        URL => 'http://localhost/cgi-bin/HelloWorldAsync', # only required for asynchronous services
+        URL => 'http://organization.org/cgi-bin/HelloWorldAsync', # only required for asynchronous services
 
     };
 
@@ -108,7 +108,7 @@ Key points of SADI standard:
 =item * 
 
 A SADI service consumes a single RDF document as input and generates a single RDF document as output.
-The input RDF document may contain multiple input instances (i.e. graphs), representing separate
+The input RDF document may contain multiple input instances (i.e. graphs) representing separate
 invocations of the service.
 
 =item * 
@@ -117,13 +117,15 @@ A SADI service is invoked by an HTTP POST to the service URL, using an RDF docum
 
 =item * 
 
-The structure of the input/output instances for a SADI service is described using OWL. The service provider specifies
-one input OWL class and one output OWL class which describe the structure of an input and an output instance, respectively.
+The structure of the input/output instances for a SADI service are described using OWL. 
+The service provider publishes one input OWL class and one output OWL class which describe the 
+structure of an input instance and an output instance, respectively.
 
 =item * 
 
 Metadata for a SADI service is retrieved by an HTTP GET on the service URL.  This metadata includes the
-URIs of the input and output OWL classes, among other information.
+URIs of the input and output OWL classes, as well as other information such as the service name, service
+description, etc.
 
 =back
 
@@ -131,22 +133,42 @@ The main strengths of SADI are:
 
 =over
 
-=item * No framework-specific messaging formats or ontologies are required for using SADI.
-=item * SADI supports processing multiple inputs in a single request, i.e. batch processing.
-=item * SADI supports long-running services, i.e. asynchronous services.
+=item * 
+
+No framework-specific messaging formats or ontologies are required for using SADI.
+
+=item * 
+
+SADI supports processing multiple inputs in a single request, i.e. batch processing.
+
+=item * 
+
+SADI supports long-running services, i.e. asynchronous services.
+
+=back
 
 For more information about the SADI standard, see L<http://sadiframework.org>.
 
 =head1 SYNCHRONOUS SERVICES VS ASYNCHRONOUS SERVICES
 
-A service providers may implement their services as either synchronous services (subclass of a
-SADI::Simple::SyncService) or asynchronous services (subclass of a SADI::Simple::AsyncService).  
-Callers of synchronous services must wait until the results have been computed before the service 
-returns.  As a result, synchronous services must complete before the originating HTTP request times out.  
-On the other hand, asynchronous service return immediately and are polled to obtain results.  
+Service providers may implement their SADI services as a subclass of either:
+
+=over
+
+=item C<SADI::Simple::SyncService>
+
+A service that subclasses C<SADI::Simple::SyncService> is a 
+synchronous service, which means that the service completes its computation before
+returning any response to the caller. 
+
+=item C<SADI::Simple::AsyncService>
+
+A service that subclasses C<SADI::Simple::AsyncService> is a
+an asynchronous service, which means that the service returns an immediate "ask me later"
+response to a request, and must be polled for the results.
+
+=back
 
 In general, asynchronous services are a better choice as they can run for an arbitarily long
-time.  The main advantage of synchronous services is that there is less back-and-forth messaging
+time. The main advantage of synchronous services is that there is less back-and-forth messaging
 and so they are potentially more efficient for services that perform trivial operations.
-
-1;
